@@ -48,7 +48,7 @@ class Fpm:
     # is not replicated and the target dir consists of only
     # prefix + package name + dir
     package_dir = self.buildDir + "/" + name + "/" + fullVersion + "/"
-    subdirs = ['bin', 'lib', 'lib64', 'etc', 'include', 'bin-safe', 'libexec']
+    subdirs = ['bin', 'lib', 'lib64', 'etc', 'include', 'bin-safe', 'libexec', 'WebDID']
     paths = []
     for subdir in subdirs:
       if os.path.exists(package_dir + subdir):
